Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(94)

Unified Diff: ash/shell.h

Issue 9689027: MonitorManager to manage multiple monitors. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: sync Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/screen_ash.cc ('k') | ash/shell.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/shell.h
diff --git a/ash/shell.h b/ash/shell.h
index e6af0db939fc28b2e00525c0cf7048cd2e9e680f..d2903757643b9b8b5ebeab4cb5230a26a3a9f8cf 100644
--- a/ash/shell.h
+++ b/ash/shell.h
@@ -156,8 +156,10 @@ class ASH_EXPORT Shell {
// Rotate focus through containers that can receive focus.
void RotateFocus(Direction direction);
- // Sets the screen's work area insets, this notifies observers too.
- void SetScreenWorkAreaInsets(const gfx::Insets& insets);
+ // Sets the work area insets of the monitor that contains |window|,
+ // this notifies observers too.
+ void SetMonitorWorkAreaInsets(aura::Window* window,
+ const gfx::Insets& insets);
// Add/remove observer.
void AddShellObserver(ShellObserver* observer);
« no previous file with comments | « ash/screen_ash.cc ('k') | ash/shell.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698